@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2012 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2013 BalaBit IT Ltd, Budapest, Hungary
  * Copyright (c) 1998-2012 Balázs Scheidler
  *
  * This library is free software; you can redistribute it and/or
@@ -696,6 +696,7 @@ tf_simple_func_prepare(LogTemplateFunction *self, gpointer s, LogTemplate *paren
   for (i = 0; i < argc - 1; i++)
     {
       state->argv[i] = log_template_new(parent->cfg, NULL);
+      log_template_set_escape(state->argv[i], parent->escape);
       if (!log_template_compile(state->argv[i], argv[i + 1], error))
         goto error;
     }
@@ -1372,7 +1373,7 @@ log_template_options_destroy(LogTemplateOptions *options)
 void
 log_template_options_defaults(LogTemplateOptions *options)
 {
-  memset(options, 0, sizeof(options));
+  memset(options, 0, sizeof(LogTemplateOptions));
   options->frac_digits = -1;
   options->ts_format = -1;
 }
