@@ -407,7 +407,16 @@ log_msg_parse_date(LogMessage *self, const guchar **data, gint *length, guint pa
     }
   else
     {
-      return FALSE;
+      if (left >= 1 && src[0] == '-')
+        {
+          /* NILVALUE */
+          self->timestamps[LM_TS_STAMP] = self->timestamps[LM_TS_RECVD];
+          *length = --left;
+          *data = ++src;
+          return TRUE;
+        }
+      else
+        return FALSE;
     }
 
   /* NOTE: mktime() returns the time assuming that the timestamp we
@@ -924,7 +933,8 @@ log_msg_parse_legacy(const MsgFormatOptions *parse_options,
       /* Different format */
 
       /* A kernel message? Use 'kernel' as the program name. */
-      if ((self->flags & LF_INTERNAL) == 0 && ((self->pri & LOG_FACMASK) == LOG_KERN))
+      if ((self->flags & LF_INTERNAL) == 0 && ((self->pri & LOG_FACMASK) == LOG_KERN &&
+                                               (self->flags & LF_LOCAL) != 0))
         {
           log_msg_set_value(self, LM_V_PROGRAM, "kernel", 6);
         }
