@@ -365,7 +365,7 @@ test_nvtable_indirect()
   /* NOTE: the sizing of the NVTable can easily be broken, it is sized
      to make it possible to store one direct entry */
 
-  tab = nv_table_new(STATIC_VALUES, 0, 138);
+  tab = nv_table_new(STATIC_VALUES, 0, 138+3);  // direct: +3
   success = nv_table_add_value(tab, STATIC_HANDLE, STATIC_NAME, 4, value, 128, NULL);
   TEST_ASSERT(success == TRUE);
 
@@ -437,7 +437,7 @@ test_nvtable_indirect()
   /* the new entry will not fit to the space allocated to the old and neither to the NVTable */
 
   /* setup code: add static and a dynamic-direct entry */
-  tab = nv_table_new(STATIC_VALUES, 1, 150);
+  tab = nv_table_new(STATIC_VALUES, 1, 154+3+4);  // direct: +3, indirect: +4
   success = nv_table_add_value(tab, STATIC_HANDLE, STATIC_NAME, 4, value, 128, NULL);
   TEST_ASSERT(success == TRUE);
   success = nv_table_add_value(tab, handle, name, strlen(name), value, 1, NULL);
@@ -535,7 +535,7 @@ test_nvtable_indirect()
 
   /* one that is too large */
 
-  tab = nv_table_new(STATIC_VALUES, STATIC_VALUES, 256);
+  tab = nv_table_new(STATIC_VALUES, 4, 256);
   success = nv_table_add_value(tab, STATIC_HANDLE, STATIC_NAME, 4, value, 128, NULL);
   TEST_ASSERT(success == TRUE);
   success = nv_table_add_value_indirect(tab, DYN_HANDLE, DYN_NAME, strlen(DYN_NAME), STATIC_HANDLE, 0, 1, 126, NULL);
@@ -600,7 +600,7 @@ test_nvtable_indirect()
 
   /* one that is too large */
 
-  tab = nv_table_new(STATIC_VALUES, STATIC_VALUES, 256);
+  tab = nv_table_new(STATIC_VALUES, 4, 256);
   success = nv_table_add_value(tab, STATIC_HANDLE, STATIC_NAME, 4, value, 128, NULL);
   TEST_ASSERT(success == TRUE);
   success = nv_table_add_value_indirect(tab, DYN_HANDLE, DYN_NAME, strlen(DYN_NAME), STATIC_HANDLE, 0, 1, 126, NULL);
